@@ -7,24 +7,26 @@ from urllib.parse import urlparse
 
 class GCSPresignedUrlRemoteWriter(object):
     key = 'gcs-url'
+    signed_url = None
 
     def __init__(self, formatter, specification):
         self.formatter = formatter
         self.specification = specification
 
+    def before_write(self):
+        self.signed_url = self.specification.get('uri')
+
+        if not self.signed_url:
+            self.signed_url = input("Enter the signed url: ")
+
     def write(self, dataframe: DataFrame):
-        signed_url = self.specification.get('uri')
-
-        if not signed_url:
-            signed_url = input("Enter the signed url: ")
-
         buffer = StringIO()
 
         self.formatter.format(dataframe=dataframe,
                               path_or_buffer=buffer)
 
         try:
-            response = requests.put(signed_url,
+            response = requests.put(self.signed_url,
                                     data=buffer.getvalue())
             response.raise_for_status()
         except Exception as e:
