@@ -13,6 +13,18 @@ class TestSerializersConfiguration(object):
         assert rules is not None
         assert isinstance(rules, dict) is True
 
+    def test_mysql(self, mysql_writer_sample):
+        rules = SerializersConfiguration.get_rules(mysql_writer_sample)
+
+        assert rules is not None
+        assert isinstance(rules, dict) is True
+
+    def test_postgresql(self, postgresql_writer_sample):
+        rules = SerializersConfiguration.get_rules(postgresql_writer_sample)
+
+        assert rules is not None
+        assert isinstance(rules, dict) is True
+
     def test_s3(self, s3_writer_sample):
         rules = SerializersConfiguration.get_rules(s3_writer_sample)
 
